whatsdigger library

Functions

getGroupID(String link) String
gets a whatsapp group link and returns its id
getLinkHead() String
returns link without group id
linkdigger(String group_link) Future<Map<String, String>?>
return map with group name and group picture link in future value callback for example
webDigger(String web_url) Future<Set<String>?>
This Func Grab all the whatsapp groups linkes from given web page url and return set of grabbed linkes For Example